<?php

/**
* @maintainer He Wei Ping [laser@zhengmai.com.cn]
*/

// Language and character set
$lang['applang'] = '&#31616;&#20307;&#20013;&#25991;&#65288;&#32479;&#19968;&#30721;&#65289;';
$lang['appcharset'] = 'gb2312';
$lang['applocale'] = 'zh_CN';
$lang['appdbencoding'] = 'EUC_CN';
$lang['applangdir'] = 'ltr';

// Basic strings
$lang['strintro'] = '&#36814;&#20351;&#29992; phpPgAdmin&#12290;';
$lang['strlogin'] = '&#30331;&#24405;';
$lang['strloginfailed'] = '&#30331;&#24405;&#22833;&#36133;';
$lang['strserver'] = '&#26381;&#21153;&#22120;';
$lang['strlogout'] = '&#27880;&#38144;';
$lang['strowner'] = '&#25152;&#23646;&#20154;';
$lang['straction'] = '&#21151;&#33021;';
$lang['stractions'] = '&#21151;&#33021;';
$lang['strname'] = '&#21517;&#23383;';
$lang['strdefinition'] = '&#23450;&#20041;';
$lang['strsequence'] = '&#24207;&#21015;';
$lang['strsequences'] = '&#24207;&#21015;';
$lang['stroperators'] = '&#25805;&#20316;';
$lang['strtypes'] = '&#31867;&#22411;';
$lang['straggregates'] = '&#32858;&#38598;';
$lang['strproperties'] = '&#23646;&#24615;';
$lang['strbrowse'] = '&#27983;&#35272;';
$lang['strdrop'] = '&#21024;&#38500;';
$lang['strdropped'] = '&#24050;&#21024;&#38500;';
$lang['strnull'] = '&#31354;';
$lang['strnotnull'] = '&#38750;&#31354;';
$lang['strprev'] = '&#19978;&#19968;&#20010;';
$lang['strnext'] = '&#19979;&#19968;&#20010;';
$lang['strfailed'] = '&#22833;&#36133;';
$lang['strcreate'] = '&#21019;&#24314;';
$lang['strcomment'] = '&#27880;&#37322;';
//$lang['strnext'] = 'Next';
$lang['strlength'] = '&#38271;&#24230;';
$lang['strdefault'] = '&#40664;&#35748;';
$lang['stralter'] = '&#26356;&#25913;';
$lang['strcancel'] = '&#21462;&#28040;';
$lang['strsave'] = '&#23384;&#20648;';
$lang['strinsert'] = '&#25554;&#20837;';
$lang['strselect'] = '&#36873;&#21462;';
$lang['strdelete'] = '&#21024;&#38500;';
$lang['strupdate'] = '&#26356;&#26032;';
$lang['strreferences'] = '&#21442;&#32771;';
$lang['stryes'] = '&#26159;';
$lang['strno'] = '&#21542;';
$lang['stredit'] = '&#32534;&#36753;';
$lang['strrows'] = '&#34892;';
$lang['strexample'] = '&#22914;&#65306;';
$lang['strback'] = '&#36820;&#22238;';
$lang['strqueryresults'] = '&#26597;&#23547;&#32467;&#26524;';
$lang['strshow'] = '&#26174;&#31034;';
$lang['strempty'] = '&#31354;';
$lang['strlanguage'] = '&#35821;&#35328;';

// Error handling
$lang['strbadconfig'] = '&#24744;&#30340; config.inc.php &#24050;&#22833;&#25928;&#12290;&#24744;&#38656;&#35201;&#33258;&#34892;&#36890;&#36807; config.inc.php-ist &#20462;&#25913;&#12290;';
$lang['strnotloaded'] = '&#24744;&#30340; PHP &#20013;&#27809;&#26377;&#23436;&#25972;&#30340;&#25968;&#25454;&#24211;&#25903;&#25345;&#12290;';
$lang['strsqlerror'] = 'SQL:&#38169;&#35823;';
$lang['strinstatement'] = 'In statement&#65306;';
$lang['strinvalidparam'] = '&#26080;&#25928;&#30340;&#33050;&#26412;&#21442;&#25968;';
$lang['strnodata'] = '&#26597;&#26080;&#27492;&#34892;&#12290;';

// Tables
$lang['strnotables'] = '&#26597;&#26080;&#27492;&#34920;&#12290;';
$lang['strnotable'] = '&#26597;&#26080;&#27492;&#34920;&#12290;';
$lang['strtable'] = '&#25968;&#25454;&#34920;';
$lang['strtables'] = '&#25968;&#25454;&#34920;';
$lang['strtablecreated'] = '&#24314;&#34920;&#23436;&#25104;&#12290;';
$lang['strtablecreatedbad'] = '&#24314;&#34920;&#22833;&#36133;';
$lang['strtableneedsfield'] = '&#33267;&#23569;&#38656;&#35201;&#19968;&#20010;&#25968;&#25454;&#27573;&#12290;';
$lang['strinsertrow'] = '&#25554;&#20837;&#34892;';
$lang['strrowinserted'] = '&#25554;&#20837;&#34892;&#23436;&#25104;&#12290;';
$lang['strrowinsertedbad'] = '&#20808;&#25554;&#20837;&#34892;&#12290;';
$lang['streditrow'] = '&#26356;&#25913;&#34892;';
$lang['strrowupdated'] = '&#23436;&#25104;&#34892;&#26356;&#26032;&#12290;';
$lang['strrowupdatedbad'] = '&#26356;&#26032;&#34892;&#22833;&#36133;&#12290;';
$lang['strdeleterow'] = '&#21024;&#38500;&#34892;';
$lang['strconfdeleterow'] = '&#30495;&#30340;&#35201;&#38500;&#25152;&#26377;&#30340;&#34892;&#65311;';
$lang['strrowdeleted'] = '&#21024;&#38500;&#38500;&#34892;&#23436;&#25104;&#12290;';
$lang['strrowdeletedbad'] = '&#38500;&#34892;&#22833;&#36133;&#12290;';
$lang['strsaveandrepeat'] = '&#37325;&#22797;&#23384;&#20648;';
$lang['strconfemptytable'] = '&#30495;&#30340;&#35201;&#28165;&#31354;&quot;%s&quot;&#25968;&#25454;&#34920;&#65311;';
$lang['strtableemptied'] = '&#25968;&#25454;&#34920;&#28165;&#31354;&#23436;&#25104;&#12290;';
$lang['strtableemptiedbad'] = '&#25968;&#25454;&#34920;&#28165;&#31354;&#22833;&#36133;&#12290;';
$lang['strconfdroptable'] = '&#30495;&#30340;&#35201;&#21024;&#38500;&#38500;&quot;%s&quot;&#25968;&#25454;&#34920;&#65311;';
$lang['strtabledropped'] = '&#21892;&#38500;&#25968;&#25454;&#34920;&#23436;&#25104;&#12290;';
$lang['strtabledroppedbad'] = '&#21024;&#38500;&#25968;&#25454;&#34920;&#22833;&#36133;&#12290;';

// Users
$lang['struseradmin'] = '&#29992;&#25143;&#31649;&#29702;';
$lang['struser'] = '&#29992;&#25143;';
$lang['strusers'] = '&#29992;&#25143;';
$lang['strusername'] = '&#29992;&#21517;';
$lang['strpassword'] = '&#23494;&#30721;';
$lang['strsuper'] = '&#36229;&#32423;&#29992;&#25143;';
$lang['strcreatedb'] = '&#24314;&#24211;';
$lang['strexpires'] = '&#36807;&#26399;';
$lang['strnousers'] = '&#26597;&#26080;&#27492;&#29992;&#25143;';

// Groups
$lang['strgroupadmin'] = '&#32452;&#31649;&#29702;';
$lang['strgroup'] = '&#32452;';
$lang['strgroups'] = '&#32676;&#32452;';
$lang['strnogroups'] = '&#26597;&#26080;&#32676;&#32452;&#12290;';
$lang['strcreategroup'] = '&#21019;&#24314;&#32452;';
$lang['strshowallgroups'] = '&#26174;&#31034;&#25152;&#26377;&#32676;&#32452;';
$lang['strgroupneedsname'] = '&#20320;&#24517;&#32473;&#24744;&#32452;&#21629;&#21517;&#12290;';
$lang['strgroupcreated'] = '&#24314;&#32452;&#23436;&#25104;&#12290;';
$lang['strgroupcreatedbad'] = '&#24314;&#32452;&#22833;&#36133;&#12290;';
$lang['strconfdropgroup'] = '&#30495;&#30340;&#35201;&#21024;&#38500;&quot;%s&quot;&#32452;&#65311;';
$lang['strgroupdropped'] = '&#21024;&#38500;&#32452;&#23436;&#25104;&#12290;';
$lang['strgroupdroppedbad'] = '&#21024;&#38500;&#32452;&#22833;&#36133;&#12290;';
$lang['strmembers'] = '&#25104;&#21592;';

// Privilges
$lang['strprivileges'] = '&#29305;&#26435;';
$lang['strgrant'] = '&#36171;&#20104;';
$lang['strrevoke'] = '&#25764;&#22238;';

// Databases
$lang['strdatabase'] = '&#25968;&#25454;&#24211;';
$lang['strdatabases'] = '&#25968;&#25454;&#24211;';
$lang['strnodatabases'] = '&#26597;&#26080;&#27492;&#25968;&#25454;&#24211;&#12290;';
$lang['strdatabaseneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#25968;&#25454;&#24211;&#21629;&#21517;&#12290;';

// Views
$lang['strviewneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#35270;&#22270;&#21629;&#21517;&#12290;';
$lang['strviewneedsdef'] = '&#20320;&#24517;&#39035;&#23450;&#20041;&#24744;&#30340;&#35270;&#22270;&#12290;';
$lang['strcreateview'] = '&#24314;&#31435;&#35270;&#22270;';
$lang['strnoviews'] = '&#26597;&#26080;&#35270;&#22270;&#12290;';
$lang['strview'] = '&#35270;&#22270;';
$lang['strviews'] = '&#35270;&#22270;';

// Sequences
$lang['strnosequences'] = '&#26597;&#26080;&#24207;&#21015;&#12290;';
$lang['strsequencename'] = '&#24207;&#21015;&#21517;&#31216;';
$lang['strlastvalue'] = '&#26368;&#21518;&#30340;&#25968;&#30446;';
$lang['strincrementby'] = '&#22686;&#37327;&#65288;&#21152;&#65295;&#20943;&#65289;';
$lang['strmaxvalue'] = '&#26368;&#22823;&#20540;';
$lang['strminvalue'] = '&#26368;&#23567;&#20540;';
$lang['strcachevalue'] = 'cache_value';
$lang['strlogcount'] = 'log_cnt';
$lang['striscycled'] = 'is_cycled';
$lang['strreset'] = '&#37325;&#32622;';

// Indexes
$lang['strindexes'] = '&#32034;&#24341;';
$lang['strindexname'] = '&#32034;&#24341;&#21517;';
$lang['strtabname'] = 'Tab Name';
$lang['strcolumnname'] = 'Column Name';
$lang['struniquekey'] = '&#21807;&#19968;&#38190;';
$lang['strprimarykey'] = '&#20027;&#38190;';
$lang['strshowallindexes'] = '&#26174;&#31034;&#25152;&#26377;&#32034;&#24341;';
$lang['strcreateindex'] = '&#21019;&#24314;&#32034;&#24341;';
$lang['strindexneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#32034;&#24341;&#21629;&#21517;&#12290;';
$lang['strindexneedscols'] = '&#20320;&#24517;&#39035;&#32473;&#20320;&#30340;&#23383;&#27573;&#36171;&#20104;&#19968;&#20010;&#27491;&#25972;&#25968;&#12290;';
$lang['strindexcreated'] = '&#21019;&#24314;&#32034;&#24341;&#23436;&#25104;';
$lang['strindexcreatedbad'] = '&#21019;&#24314;&#32034;&#24341;&#22833;&#36133;.';
$lang['strconfdropindex'] = '&#30495;&#30340;&#35201;&#21024;&#38500;&quot;%s&quot;&#32034;&#24341;&#65311;';
$lang['strindexdropped'] = '&#21024;&#38500;&#32034;&#24341;&#23436;&#25104;&#12290;';
$lang['strindexdroppedbad'] = '&#21024;&#38500;&#38500;&#32034;&#24341;&#22833;&#36133;&#12290;';

// Rules
$lang['strrules'] = '&#35268;&#21017;';
$lang['strrule'] = '&#35268;&#21017;';
$lang['strnorules'] = '&#26597;&#26080;&#27492;&#35268;&#21017;';
$lang['strcreaterule'] = '&#21019;&#24314;&#35268;&#21017;';

// Tables
$lang['strfield'] = '&#21015;';
$lang['strfields'] = '&#21015;';
$lang['strtype'] = '&#31867;&#22411;';
$lang['strvalue'] = '&#20540;';
$lang['strshowalltables'] = '&#31034;&#25152;&#26377;&#34920;&#12290;';
$lang['strunique'] = '&#21807;&#19968;';
$lang['strprimary'] = '&#20027;';
$lang['strkeyname'] = '&#38190;&#21517;';
$lang['strnumfields'] = '&#21015;&#25968;';
$lang['strcreatetable'] = '&#21019;&#24314;&#34920;';
$lang['strtableneedsname'] = '&#20320;&#24517;&#24744;&#30340;&#32034;&#24341;&#21629;&#21517;&#12290;';
$lang['strtableneedscols'] = '&#20320;&#24517;&#39035;&#32473;&#20320;&#30340;&#23383;&#27573;&#36171;&#20104;&#19968;&#20010;&#27491;&#25972;&#25968;&#12290;';
$lang['strexport'] = '&#23548;&#20986;';
$lang['strconstraints'] = '&#24378;&#21046;';
$lang['strcolumns'] = '&#21015;';

// Functions
$lang['strnofunctions'] = '&#26597;&#26080;&#27492;&#20989;&#25968;';
$lang['strfunction'] = '&#20989;&#25968;';
$lang['strfunctions'] = '&#20989;&#25968;';
$lang['strreturns'] = 'Returns';
$lang['strarguments'] = '&#21442;&#25968;';
$lang['strproglanguage'] = '&#35821;&#35328;';
$lang['strfunctionneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#20989;&#25968;&#21629;&#21517;&#12290;';
$lang['strfunctionneedsdef'] = '&#20320;&#24517;&#39035;&#23450;&#20041;&#24744;&#30340;&#20989;&#25968;&#12290;';

// Triggers
$lang['strtrigger'] = '&#35302;&#21457;&#22120;';
$lang['strtriggers'] = '&#35302;&#21457;&#22120;';
$lang['strnotriggers'] = '&#26597;&#26080;&#27492;&#35302;&#21457;&#22120;&#12290;';
$lang['strcreatetrigger'] = '&#21019;&#24314;&#35302;&#21457;&#22120;';

// Types
$lang['strtype'] = '&#31867;&#22411;';
$lang['strtypes'] = '&#31867;&#22411;';
$lang['strnotypes'] = '&#26597;&#26080;&#27492;&#31867;&#22411;&#12290;';
$lang['strcreatetype'] = '&#21019;&#24314;&#31867;&#22411;';
$lang['strconfdroptype'] = '&#30495;&#30340;&#35201;&#21024;&#38500;&quot;%s&quot;&#31867;&#22411;&#65311;';
$lang['strtypedropped'] = '&#21024;&#38500;&#31867;&#22411;&#23436;&#25104;&#12290;';
$lang['strtypedroppedbad'] = '&#21024;&#38500;&#31867;&#22411;&#22833;&#36133;&#12290;';
$lang['strtypecreated'] = '&#21019;&#24314;&#31867;&#22411;&#23436;&#25104;&#12290;';
$lang['strtypecreatedbad'] = '&#24314;&#22411;&#22833;&#36133;&#12290;';
$lang['strshowalltypes'] = '&#26174;&#31034;&#25152;&#26377;&#30340;&#31867;&#22411;';
$lang['strinputfn'] = '&#36755;&#20837;&#21151;&#33021;';
$lang['stroutputfn'] = '&#36755;&#20986;&#21151;&#33021;';
$lang['strpassbyval'] = 'Passed by val&#65311;';
$lang['stralignment'] = 'Alignment';
$lang['strelement'] = '&#20803;&#32032;';
$lang['strdelimiter'] = '&#20998;&#38548;&#31526;';
$lang['strstorage'] = '&#30913;&#30424;&#23384;&#20648;';
$lang['strtypeneedsname'] = '&#20320;&#24517;&#32473;&#24744;&#30340;&#31867;&#22411;&#21629;&#21517;&#12290;';
$lang['strtypeneedslen'] = '&#20320;&#24517;&#32473;&#24744;&#30340;&#31867;&#22411;&#23450;&#20041;&#19968;&#20010;&#38271;&#24230;&#12290;';

// Schemas
$lang['strschema'] = '&#27169;&#24335;';
$lang['strschemas'] = '&#27169;&#24335;';
$lang['strcreateschema'] = '&#21019;&#24314;&#27169;&#24335;';
$lang['strnoschemas'] = '&#27809;&#26377;&#27492;&#27169;&#24335;';
$lang['strconfdropschema'] = '&#20320;&#30830;&#23450;&#35201;&#21024;&#38500;&quot;%s&quot;&#27169;&#24335;&#20040;&#65311;';
$lang['strschemadropped'] = '&#27169;&#24335;&#24050;&#21024;&#38500;';
$lang['strschemadroppedbad'] = '&#27169;&#24335;&#21024;&#38500;&#22833;&#36133;';
$lang['strschemacreated'] = '&#27169;&#24335;&#24050;&#24314;&#31435;';
$lang['strschemacreatedbad'] = '&#21019;&#24314;&#27169;&#24335;&#22833;&#36133;';
$lang['strshowallschemas'] = '&#26174;&#31034;&#25152;&#26377;&#27169;&#24335;?';
$lang['strschemaneedsname'] = '&#24517;&#39035;&#32473;&#27169;&#24335;&#21629;&#21517;';

$lang['strcreated'] = '&#21019;&#24314;&#23436;&#25104;';
$lang['strok'] = '&#23436;&#25104;';
$lang['strencoding'] = '&#32534;&#30721;';
$lang['strsql'] = 'SQL&#30721;';
$lang['stradmin'] = '&#31649;&#29702;';
$lang['strvacuum'] = '&#28165;&#31354;';
$lang['stranalyze'] = '&#20998;&#26512;';
$lang['strreindex'] = '&#37325;&#24314;&#32034;&#24341;';
$lang['strrun'] = '&#25191;&#34892;';
$lang['stradd'] = '&#21019;&#24314;';
$lang['strformat'] = '&#26684;&#24335;&#21270;';
$lang['strtablename'] = '&#36164;&#26009;&#34920;&#21517;&#31216;';
$lang['strfieldneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#25968;&#25454;&#27573;&#21629;&#21517;';
$lang['struserupdated'] = '&#29992;&#25143;&#26356;&#26032;';
$lang['struserupdatedbad'] = '&#29992;&#25143;&#26356;&#26032;';
$lang['strshowallusers'] = '&#26174;&#31034;&#25152;&#26377;&#29992;&#25143;';
$lang['strcreateuser'] = '&#21019;&#24314;&#29992;&#25143;';
$lang['strusercreated'] = '&#21019;&#24314;&#29992;&#25143;&#23436;&#25104;';
$lang['strusercreatedbad'] = '&#21019;&#24314;&#29992;&#25143;&#22833;&#36133;';
$lang['strconfdropuser'] = '&#24744;&#30830;&#23450;&#35201;&#21024;&#38500;&#29992;&#25143;&quot;%s&quot;&#20040;&#65311;';
$lang['struserdropped'] = '&#29992;&#25143;&#21024;&#38500;&#23436;&#25104;';
$lang['struserdroppedbad'] = '&#21024;&#38500;&#29992;&#25143;&#22833;&#36133;';
$lang['strnogroup'] = '&#26597;&#26080;&#27492;&#32676;&#32452;&#12290;';
$lang['strprivilege'] = '&#29305;&#26435;';
$lang['strgranted'] = '&#29305;&#26435;&#36171;&#20104;&#23436;&#25104;';
$lang['strgrantfailed'] = '&#29305;&#26435;&#36171;&#20104;&#22833;&#36133;';
$lang['strgrantuser'] = '&#29305;&#26435;&#36171;&#20104;&#29992;&#25143;';
$lang['strgrantgroup'] = '&#29305;&#26435;&#36171;&#20104;&#32452;';
$lang['strshowalldatabases'] = '&#26174;&#31034;&#25152;&#26377;&#25968;&#25454;&#24211;';
$lang['strnodatabase'] = '&#26597;&#26080;&#27492;&#25968;&#25454;&#24211;&#12290;';
$lang['strcreatedatabase'] = '&#21019;&#24314;&#25968;&#25454;&#24211;';
$lang['strdatabasename'] = '&#25968;&#25454;&#24211;&#21517;&#31216;';
$lang['strdatabasecreated'] = '&#21019;&#24314;&#25968;&#25454;&#24211;&#23436;&#25104;';
$lang['strdatabasecreatedbad'] = '&#21019;&#24314;&#25968;&#25454;&#24211;&#22833;&#36133;';
$lang['strconfdropdatabase'] = '&#24744;&#30830;&#23450;&#35201;&#21024;&#38500;&#25968;&#25454;&#24211;&quot;%s&quot;&#20040;&#65311;';
$lang['strdatabasedropped'] = '&#25968;&#25454;&#24211;&#21024;&#38500;&#23436;&#25104;';
$lang['strdatabasedroppedbad'] = '&#21024;&#38500;&#25968;&#25454;&#24211;&#22833;&#36133;';
$lang['strentersql'] = '&#35831;&#22312;&#19979;&#26041;&#36755;&#20837;&#35201;&#25191;&#34892;&#30340;SQL&#30721;&#65306;';
$lang['strvacuumgood'] = '&#28165;&#31354;&#23436;&#25104;';
$lang['strvacuumbad'] = '&#28165;&#31354;&#22833;&#36133;';
$lang['stranalyzegood'] = '&#20998;&#26512;&#23436;&#25104;';
$lang['stranalyzebad'] = '&#20998;&#26512;&#22833;&#36133;';
$lang['strshowallviews'] = '&#26174;&#31034;&#25152;&#35270;&#22270;';
$lang['strnoview'] = '&#26597;&#26080;&#27492;&#35270;&#22270;';
$lang['strviewname'] = '&#35270;&#22270;&#21517;&#31216;';
$lang['strviewcreated'] = '&#21019;&#24314;&#35270;&#22270;&#23436;&#25104;';
$lang['strviewcreatedbad'] = '&#21019;&#24314;&#35270;&#22270;&#22833;&#36133;';
$lang['strconfdropview'] = '&#24744;&#30830;&#23450;&#35201;&#21024;&#38500;&#35270;&#22270;&quot;%s&quot;&#20040;&#65311;';
$lang['strviewdropped'] = '&#35270;&#22270;&#21024;&#38500;&#23436;&#25104;';
$lang['strviewdroppedbad'] = '&#21024;&#38500;&#35270;&#22270;&#22833;&#36133;';
$lang['strviewupdated'] = '&#35270;&#22270;&#26356;&#26032;&#23436;&#25104;';
$lang['strviewupdatedbad'] = '&#35270;&#22270;&#26356;&#26032;&#22833;&#36133;';
$lang['strshowallsequences'] = '&#26174;&#31034;&#25152;&#26377;&#24207;&#21015;';
$lang['strnosequence'] = '&#26597;&#26080;&#27492;&#24207;&#21015;';
$lang['strcreatesequence'] = '&#21019;&#24314;&#24207;&#21015;';
$lang['strstartvalue'] = '&#36215;&#22987;&#20540;';
$lang['strsequenceneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#24207;&#21015;&#21629;&#21517;';
$lang['strsequencecreated'] = '&#21019;&#24314;&#24207;&#21015;&#23436;&#25104;';
$lang['strsequencecreatedbad'] = '&#21019;&#24314;&#24207;&#21015;&#22833;&#36133;';
$lang['strconfdropsequence'] = '&#24744;&#30830;&#23450;&#35201;&#21024;&#38500;&#24207;&#21015;&quot;%s&quot;&#20040;&#65311;';
$lang['strsequencedropped'] = '&#24207;&#21015;&#21024;&#38500;&#23436;&#25104;';
$lang['strsequencedroppedbad'] = '&#21024;&#38500;&#24207;&#21015;&#22833;&#36133;';
$lang['strnoindex'] = '&#26597;&#26080;&#27492;&#32034;&#24341;';
$lang['strnoindexes'] = '&#26597;&#26080;&#27492;&#32034;&#24341;';
$lang['strindextype'] = '&#32034;&#24341;&#30340;&#31867;&#22411;';
$lang['strshowallrules'] = '&#26174;&#31034;&#25152;&#26377;&#35268;&#21017;';
$lang['strnorule'] = '&#26597;&#26080;&#27492;&#35268;&#21017;';
$lang['strrulename'] = '&#35268;&#21017;&#21517;&#31216;';
$lang['strruleneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#35268;&#21017;&#21629;&#21517;';
$lang['strrulecreated'] = '&#21019;&#24314;&#35268;&#21017;&#23436;&#25104;';
$lang['strrulecreatedbad'] = '&#21019;&#24314;&#35268;&#21017;&#22833;&#36133;';
$lang['strconfdroprule'] = '&#24744;&#30830;&#23450;&#35201;&#25226;&#35268;&#21017;&quot;%s&quot;&#22312;&#36164;&#26009;&#24211;&quot;%s&quot;&#20013;&#21024;&#38500;&#20040;&#65311;';
$lang['strruledropped'] = '&#35268;&#21017;&#21024;&#38500;&#23436;&#25104;';
$lang['strruledroppedbad'] = '&#21024;&#38500;&#35268;&#21017;&#22833;&#36133;';
$lang['strshowallconstraints'] = '&#26174;&#31034;&#25152;&#26377;&#24378;&#21046;';
$lang['strnoconstraints'] = '&#26597;&#26080;&#27492;&#24378;&#21046;';
$lang['strcreateconstraint'] = '&#21019;&#24314;&#24378;&#21046;';
$lang['strconstraintcreated'] = '&#21019;&#24314;&#24378;&#21046;&#23436;&#25104;';
$lang['strconstraintcreatedbad'] = '&#21019;&#24314;&#24378;&#21046;&#22833;&#36133;';
$lang['strconfdropconstraint'] = '&#24744;&#30830;&#23450;&#35201;&#25226;&#24378;&#21046;&quot;%s&quot;&#22312;&#36164;&#26009;&#24211;&quot;%s&quot;&#20013;&#21024;&#38500;&#20040;&#65311;';
$lang['strconstraintdropped'] = '&#21024;&#38500;&#24378;&#21046;&#23436;&#25104;';
$lang['strconstraintdroppedbad'] = '&#21024;&#38500;&#24378;&#21046;&#22833;&#36133;';
$lang['straddpk'] = '&#26032;&#22686;&#20027;&#38190;';
$lang['strpkneedscols'] = '&#20027;&#38190;&#39035;&#35201;&#33267;&#23569;&#19968;&#21015;';
$lang['strpkadded'] = '&#20027;&#38190;&#26032;&#22686;&#23436;&#25104;';
$lang['strpkaddedbad'] = '&#26032;&#22686;&#20027;&#38190;&#22833;&#36133;';
$lang['strshowallfunctions'] = '&#26174;&#31034;&#25152;&#26377;&#20989;&#25968;';
$lang['strnofunction'] = '&#26597;&#26080;&#27492;&#20989;&#25968;';
$lang['strcreatefunction'] = '&#21019;&#24314;&#20989;&#25968;';
$lang['strfunctionname'] = '&#20989;&#25968;&#21517;&#31216;';
$lang['strfunctioncreated'] = '&#21019;&#24314;&#20989;&#25968;&#23436;&#25104;';
$lang['strfunctioncreatedbad'] = '&#21019;&#24314;&#20989;&#25968;&#22833;&#36133;';
$lang['strconfdropfunction'] = '&#24744;&#30830;&#23450;&#35201;&#21024;&#38500;&#20989;&#25968;&quot;%s&quot;&#20040;&#65311;';
$lang['strfunctiondropped'] = '&#21024;&#38500;&#20989;&#25968;&#23436;&#25104;.';
$lang['strfunctiondroppedbad'] = '&#21024;&#38500;&#20989;&#25968;&#22833;&#36133;';
$lang['strfunctionupdated'] = '&#26356;&#26032;&#20989;&#25968;&#23436;&#25104;.';
$lang['strfunctionupdatedbad'] = '&#26356;&#26032;&#20989;&#25968;&#22833;&#36133;';
$lang['strshowalltriggers'] = '&#26174;&#31034;&#25152;&#26377;&#35302;&#21457;&#22120;';
$lang['strnotrigger'] = '&#26597;&#26080;&#27492;&#35302;&#21457;&#22120;';
$lang['strtriggerneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#35302;&#21457;&#22120;&#21629;&#21517;';
$lang['strtriggerneedsfunc'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#35302;&#21457;&#22120;&#19968;&#20010;&#20989;&#25968;';
$lang['strtriggercreated'] = '&#21019;&#24314;&#35302;&#21457;&#22120;&#23436;&#25104;';
$lang['strtriggercreatedbad'] = '&#21019;&#24314;&#35302;&#21457;&#22120;&#22833;&#36133;';
$lang['strconfdroptrigger'] = '&#24744;&#30830;&#23450;&#35201;&#25226;&#35302;&#21457;&#22120;&quot;%s&quot;&#22312;&#36164;&#26009;&#24211;&quot;%s&quot;&#20013;&#21024;&#38500;&#20040;&#65311;';
$lang['strtriggerdropped'] = '&#21024;&#38500;&#35302;&#21457;&#22120;&#23436;&#25104;.';
$lang['strtriggerdroppedbad'] = '&#21024;&#38500;&#35302;&#21457;&#22120;&#22833;&#36133;';
$lang['strnotype'] = '&#26597;&#26080;&#27492;&#31867;&#22411;';
$lang['strtypename'] = '&#31867;&#22411;&#21517;&#31216;';
$lang['strnoschema'] = '&#26597;&#26080;&#27492;&#27169;&#24335;';
$lang['strschemaname'] = '&#27169;&#24335;&#21517;&#31216;';
$lang['strreport'] = '&#25253;&#34920;';
$lang['strreports'] = '&#25253;&#34920;';
$lang['strshowallreports'] = '&#26174;&#31034;&#25152;&#26377;&#25253;&#34920;';
$lang['strnoreports'] = '&#26597;&#26080;&#27492;&#25253;&#34920;';
$lang['strcreatereport'] = '&#21019;&#24314;&#25253;&#34920;';
$lang['strreportdropped'] = '&#21019;&#24314;&#25253;&#34920;&#23436;&#25104;.';
$lang['strreportdroppedbad'] = '&#21024;&#38500;&#25253;&#34920;&#22833;&#36133;';
$lang['strconfdropreport'] = '&#24744;&#30830;&#23450;&#35201;&#21024;&#38500;&#25253;&#34920;&quot;%s&quot;&#20040;&#65311;';
$lang['strreportneedsname'] = '&#20320;&#24517;&#39035;&#32473;&#24744;&#30340;&#25253;&#34920;&#21629;&#21517;';
$lang['strreportcreated'] = '&#20648;&#23384;&#25253;&#34920;&#23436;&#25104;';
$lang['strreportcreatedbad'] = '&#20648;&#23384;&#25253;&#34920;&#22833;&#36133;';



// Miscellaneous
$lang['strtopbar'] = '%s &#26550;&#20110; %s&#65306;%s &#65293; &#24744;&#26159; &quot;%s&quot;';
$lang['strtimefmt'] = 'jS M, Y g:iA';

?>
